Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1595)

Unified Diff: Source/platform/mac/ThemeMac.h

Issue 368003002: Check if drawFocusRingMaskWithFrame:inView: exists when drawing focus ring (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/paint/ThemePainterMac.mm ('k') | Source/platform/mac/ThemeMac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/mac/ThemeMac.h
diff --git a/Source/platform/mac/ThemeMac.h b/Source/platform/mac/ThemeMac.h
index ed3bf092aaff913b26ebc0fd80ca23d164e63a24..db703df35ec8dcf65b5744dc20a69b9c1832f88e 100644
--- a/Source/platform/mac/ThemeMac.h
+++ b/Source/platform/mac/ThemeMac.h
@@ -67,9 +67,11 @@ public:
static PLATFORM_EXPORT IntRect inflateRectForAA(const IntRect&);
// Inflate an IntRect to account for its focus ring. This is only used when
// BUTTON_CELL_DRAW_WITH_FRAME_DRAWS_FOCUS_RING is defined (otherwise, the focus ring's
// bounds could be accurately computed with -[NSCell focusRingMaskBoundsForFrame:inView:]).
static PLATFORM_EXPORT IntRect inflateRectForFocusRing(const IntRect&);
+
+ static PLATFORM_EXPORT bool drawWithFrameDrawsFocusRing();
};
} // namespace blink
« no previous file with comments | « Source/core/paint/ThemePainterMac.mm ('k') | Source/platform/mac/ThemeMac.mm » ('j') | no next file with comments »
@@ -67,9 +67,11 @@ public:
static PLATFORM_EXPORT IntRect inflateRectForAA(const IntRect&);
// Inflate an IntRect to account for its focus ring. This is only used when
- // BUTTON_CELL_DRAW_WITH_FRAME_DRAWS_FOCUS_RING is defined (otherwise, the focus ring's
+ // drawWithFrameDrawsFocusRing() returns true (otherwise, the focus ring's
// bounds could be accurately computed with -[NSCell focusRingMaskBoundsForFrame:inView:]).
static PLATFORM_EXPORT IntRect inflateRectForFocusRing(const IntRect&);

Powered by Google App Engine
This is Rietveld 408576698